// 每条蛇定义成一个对象
import { AcGameObject } from "./AcGameObject";
import { Cell } from "./Cell";

// 需要继承自绘制基础类 AcGameObject ,用于蛇的绘制刷新
export class Snake extends AcGameObject {
    // 参数:蛇的信息 info ,当前游戏地图 gamemap
    constructor(info, gamemap) {
        super();

        // 每条蛇的 id 用于区分每条蛇, color 用于定义蛇的颜色
        this.id = info.id;
        this.color = info.color;
        // 调用地图的引用获取一些地图参数,例如:每个格子的边长
        this.gamemap = gamemap;

        // 蛇初始只有一个点(蛇头),初始时只需要定义出蛇头即可。初始坐标为每条蛇的起始位置
        // cells[] 存放蛇的身体, cells[0] 存放蛇头
        this.cells = [new Cell(info.r, info.c)]
    }

    start() {

    }

    update() {
        // 每次更新蛇类对象都重新调用一次渲染
        this.render();
    }

    // render 不来自基类,需要本类自己实现
    render() {
        // 取出单元格长度引用和画布
        const L = this.gamemap.L;
        const ctx = this.gamemap.ctx;

        // 画圆(蛇的身体结点)
        ctx.fillStyle = this.color;
        // 蛇的身体不止一节,需要枚举画出所有的肢结。of 遍历 cells 值
        for(const cell of this.cells){
            // 画成正方形
            // ctx.fillRect(cell.c * L, cell.r * L, L, L);

            // 画成圆形
            ctx.beginPath();
            ctx.arc(cell.x * L, cell.y * L, L * 0.5, 0, 2*Math.PI);
            // 填充颜色
            ctx.fill();
        }
    }
}